@@ -74,14 +74,22 @@ class AdsAPIError(Exception):
     https://developers.facebook.com/docs/reference/ads-api/error-reference/
     """
     def __init__(self, error):
-        data = json.load(error)
-        self.error = data
-        self.message = data['error']['message']
-        self.code = data['error']['code']
-        self.type = data['error']['type']
+        try:
+            self.error = json.load(error)
+        except ValueError:
+            self.error = error
+            self.message = None
+            self.code = None
+            self.type = None
+            self.str = '{} (invalid JSON)'.format(error)
+        else:
+            self.message = self.error.get('error', {}).get('message')
+            self.code = self.error.get('error', {}).get('code')
+            self.type = self.error.get('error', {}).get('type')
+            self.str = '(%s %s) %s' % (self.type, self.code, self.message)
 
     def __str__(self):
-        return '(%s %s) %s' % (self.type, self.code, self.message)
+        return self.str
 
 
 class AdsAPI(object):
@@ -860,7 +868,7 @@ class AdsAPI(object):
             account_id, name, "WEBSITE", description=description, rule=rule,
             retention_days=retention_days, batch=batch)
 
-    def create_lookalike_audiecne(self, account_id, name, audience_id,
+    def create_lookalike_audience(self, account_id, name, audience_id,
                                   lookalike_spec, batch=False):
         """Create a lookalike audience for the given target audience."""
         path = "act_%s/customaudiences" % account_id
